.. _reference:

=============
API Reference
=============

This section contains a summary of SymPy modules, functions, classes, and
methods. All functions and objects implemented in the ``sympy`` core
subpackage are documented below.

..  rst-class:: column

:ref:`Basics <basic_modules>`
-------------------------------------------------------

   Contains a description of operations for the basic modules. Subcategories include: *absolute basics*,
   *manipulation*, *assumptions*, *functions*, *simplification*, *calculus*, *solvers*, and some
   other subcategories.


..  rst-class:: column

:ref:`Code Generation <codegen_module>`
-------------------------------------------------------

   Contains a description of methods for the generation of compilable and executable code.


..  rst-class:: column

:ref:`Logic <logic>`
-------------------------------------------------------

   Contains method details for the *logic* and *sets* modules.

..  rst-class:: column

:ref:`Matrices <matrices_modules>`
-------------------------------------------------------

   Discusses methods for the matrices, tensor and vector modules.

..  rst-class:: column

:ref:`Number Theory <numtheory_module>`
-------------------------------------------------------

   Documents methods for the Number theory module.

..  rst-class:: column

:ref:`Physics <physics-docs>`
-------------------------------------------------------

   Contains documentation for Physics methods.

..  rst-class:: column

:ref:`Utilities <utilities>`
-------------------------------------------------------

   Contains docstrings for methods of several utility modules. Subcategories
   include: *Interactive*, *Parsing*, *Printing*, *Testing*, *Utilities*.


..  rst-class:: column

:ref:`Topics <topics>`
-------------------------------------------------------

   Contains method docstrings for several modules. Subcategories include : *Plotting*,
   *Polynomials*, *Geometry*, *Category Theory*, *Cryptography*, *Differential*, *Holonomic*,
   *Lie Algebra*, and *Stats*.


.. toctree::
   :hidden:
   :maxdepth: 2

   public/basics/index.rst
   public/codegeneration/index.rst
   public/logic/index.rst
   public/matrices/index.rst
   public/numbertheory/index.rst
   public/physics/index.rst
   public/utilities/index.rst
   public/topics/index.rst
